@@ -1,5 +1,5 @@
 /* board.h -- game board for falling blocks game.  -*- C++ -*-
-   Copyright (C) 2011-2012 Gerardo Ballabio
+   Copyright (C) 2011-2015 Gerardo Ballabio
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@ private:
   int empty;
 
   // counters
-  int bmin, bmax, bsuper, bsize, isuper;
+  int bmin, bmax, bsuper, bsize, isuper, nsuper;
   int level, speed, lines, score;
   std::vector<int> filled;
 
