@@ -1,5 +1,5 @@
 /* cube.cc -- spatial groups for cubic bricks.  -*- C++ -*-
-   Copyright (C) 2011-2013 Gerardo Ballabio
+   Copyright (C) 2011-2015 Gerardo Ballabio
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -184,7 +184,7 @@ Gdk::Rectangle group_cube::board_size(int size, int rows, int cols,
 }
 
 void group_cube::draw_brick(Cairo::RefPtr<Cairo::Context> context,
-			    const coords &c, const Gdk::Color &color,
+			    const coords &c, const Gdk::RGBA &color,
 			    int size) const
 {
   const double lwidth = 2.0, margin = (lwidth + 1.0) * 0.5;
@@ -204,20 +204,20 @@ void group_cube::draw_brick(Cairo::RefPtr<Cairo::Context> context,
   context->line_to((c.x + 1) * size + c.y * offset1 - margin,
 		   -c.z * size + c.y * offset2 + margin);
   context->close_path();
-  context->set_source_rgba(color.get_red_p(), color.get_green_p(),
-			   color.get_blue_p(), 0.8);
+  context->set_source_rgba(color.get_red(), color.get_green(),
+			   color.get_blue(), 0.8);
   context->fill();
 
   context->rectangle(c.x * size + c.y * offset1 + margin,
 		     -c.z * size + c.y * offset2 + margin,
 		     size - 2.0 * margin, size - 2.0 * margin);
-  context->set_source_rgba(color.get_red_p(), color.get_green_p(),
-			   color.get_blue_p(), 1.0);
+  context->set_source_rgba(color.get_red(), color.get_green(),
+			   color.get_blue(), 1.0);
   context->stroke();
 }
 
 void group_cube::draw_shadow(Cairo::RefPtr<Cairo::Context> context,
-			     const coords &c, const Gdk::Color &color,
+			     const coords &c, const Gdk::RGBA &color,
 			     int size) const
 {
   const double lwidth = 2.0, margin = (lwidth + 1.0) * 0.5;
@@ -229,9 +229,8 @@ void group_cube::draw_shadow(Cairo::RefPtr<Cairo::Context> context,
 		     size - 2.0 * margin, size - 2.0 * margin);
 
   const double back = 0.8;
-  context->set_source_rgba(color.get_red_p() * back,
-			   color.get_green_p() * back,
-			   color.get_blue_p() * back, 1.0);
+  context->set_source_rgba(color.get_red() * back, color.get_green() * back,
+			   color.get_blue() * back, 1.0);
   context->stroke();
 
   context->rectangle(c.x * size + c.y * offset1 + margin,
@@ -239,9 +238,8 @@ void group_cube::draw_shadow(Cairo::RefPtr<Cairo::Context> context,
 		     size - 2.0 * margin, size - 2.0 * margin);
 
   const double front = 0.9;
-  context->set_source_rgba(color.get_red_p() * front,
-			   color.get_green_p() * front,
-			   color.get_blue_p() * front, 1.0);
+  context->set_source_rgba(color.get_red() * front, color.get_green() * front,
+			   color.get_blue() * front, 1.0);
   context->stroke();
 }
 
