@@ -1,5 +1,5 @@
 /* hexagon.cc -- spatial groups for hexagonal bricks.  -*- C++ -*-
-   Copyright (C) 2011-2012 Gerardo Ballabio
+   Copyright (C) 2011-2015 Gerardo Ballabio
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -162,7 +162,7 @@ Gdk::Rectangle group_hexagon::board_size(int size, int rows, int cols,
 }
 
 void group_hexagon::draw_brick(Cairo::RefPtr<Cairo::Context> context,
-			       const coords &c, const Gdk::Color &color,
+			       const coords &c, const Gdk::RGBA &color,
 			       int size) const
 {
   if (type(c) < 0)
@@ -183,16 +183,16 @@ void group_hexagon::draw_brick(Cairo::RefPtr<Cairo::Context> context,
 		   (c.y + 2) * yunit - ymargin);
   context->close_path();
 
-  context->set_source_rgba(color.get_red_p(), color.get_green_p(),
-			   color.get_blue_p(), 0.8);
+  context->set_source_rgba(color.get_red(), color.get_green(),
+			   color.get_blue(), 0.8);
   context->fill_preserve();
-  context->set_source_rgba(color.get_red_p(), color.get_green_p(),
-			   color.get_blue_p(), 1.0);
+  context->set_source_rgba(color.get_red(), color.get_green(),
+			   color.get_blue(), 1.0);
   context->stroke();
 }
 
 void group_hexagon::draw_shadow(Cairo::RefPtr<Cairo::Context> context,
-				const coords &c, const Gdk::Color &color,
+				const coords &c, const Gdk::RGBA &color,
 				int size) const
 {
   if (type(c) < 0)
@@ -214,9 +214,8 @@ void group_hexagon::draw_shadow(Cairo::RefPtr<Cairo::Context> context,
   context->close_path();
 
   const double dark = 0.8;
-  context->set_source_rgba(color.get_red_p() * dark,
-			   color.get_green_p() * dark,
-			   color.get_blue_p() * dark, 1.0);
+  context->set_source_rgba(color.get_red() * dark, color.get_green() * dark,
+			   color.get_blue() * dark, 1.0);
   context->stroke();
 }
 
