@@ -1,5 +1,5 @@
 /* preferences.cc -- preferences dialog for falling blocks game.  -*- C++ -*-
-   Copyright (C) 2011-2015 Gerardo Ballabio
+   Copyright (C) 2011-2017 Gerardo Ballabio
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -121,9 +121,9 @@ void PrefsDialog::on_width_spin_signal_value_changed()
     width2 = get_width();
 }
 
-void PrefsDialog::on_mode_combo1_signal_changed()
+void PrefsDialog::on_mode1_combo_signal_changed()
 {
-  mode_box2.set_sensitive(get_mode1() == 1);
+  mode2_box.set_sensitive(get_mode1() == 1);
 }
 
 void PrefsDialog::on_bricks_spin1_signal_value_changed()
@@ -150,39 +150,48 @@ void PrefsDialog::on_three_cell_editing_started(Gtk::CellEditable *cell,
 
 PrefsDialog::PrefsDialog(Gtk::Window &parent)
   : Gtk::Dialog("Preferences", parent, true), // modal dialog
+    page_game_box(Gtk::ORIENTATION_VERTICAL),
+    geometry_box(Gtk::ORIENTATION_VERTICAL),
+    width_box(Gtk::ORIENTATION_HORIZONTAL),
+    depth_box(Gtk::ORIENTATION_HORIZONTAL),
+    game_box(Gtk::ORIENTATION_VERTICAL),
+    mode1_box(Gtk::ORIENTATION_HORIZONTAL),
+    mode2_box(Gtk::ORIENTATION_HORIZONTAL),
+    speed_box(Gtk::ORIENTATION_HORIZONTAL),
+    bricks_box(Gtk::ORIENTATION_HORIZONTAL),
+    empty_box(Gtk::ORIENTATION_HORIZONTAL),
+    view_box(Gtk::ORIENTATION_VERTICAL),
+    page_controls_box(Gtk::ORIENTATION_VERTICAL),
     width2(10), width3(6), edit_keys(0)
 {
   get_vbox()->pack_start(notebook);
   notebook.set_border_width(10);
 
   // first tab
-  notebook.append_page(tab_game, "Game");
+  notebook.append_page(page_game_box, "Game");
 
-  tab_game.set_border_width(12);
-  tab_game.set_spacing(18);
-
-  tab_game.pack_start(geometry_box1, Gtk::PACK_SHRINK);
-  geometry_box1.set_spacing(6);
-  geometry_box1.pack_start(geometry_heading);
+  page_game_box.set_border_width(12);
+  page_game_box.set_spacing(6);
+  page_game_box.pack_start(geometry_heading, Gtk::PACK_SHRINK);
   geometry_heading.set_text("<span weight=\"bold\">Geometry</span>");
   geometry_heading.set_use_markup(true);
   geometry_heading.set_alignment(Gtk::ALIGN_START);
-  geometry_box1.pack_start(geometry_box2);
-  geometry_box2.set_margin_start(12);
-  geometry_box2.set_spacing(6);
+  page_game_box.pack_start(geometry_box, Gtk::PACK_SHRINK);
+  geometry_box.set_margin_start(12);
+  geometry_box.set_spacing(6);
   for (unsigned i=0; i<sizeof(geometry_radio)/sizeof(geometry_radio[0]); ++i)
     {
       geometry_radio[i].set_group(geometry_group);
       geometry_radio[i].set_label(brick_shape[i].description);
-      geometry_box2.pack_start(geometry_radio[i]);
+      geometry_box.pack_start(geometry_radio[i]);
       geometry_radio[i].signal_toggled().connect
 	(sigc::mem_fun(*this,
 		       &PrefsDialog::on_geometry_radio_signal_toggled));
     }
   geometry_radio[0].set_active();
-  geometry_box2.add(geometry_check);
+  geometry_box.add(geometry_check);
   geometry_check.set_label("Allow block reflection");
-  geometry_box2.pack_start(width_box, Gtk::PACK_SHRINK);
+  geometry_box.pack_start(width_box, Gtk::PACK_SHRINK);
   width_box.set_spacing(6);
   width_box.pack_start(width_label, Gtk::PACK_SHRINK);
   width_label.set_text("Board width:");
@@ -198,46 +207,45 @@ PrefsDialog::PrefsDialog(Gtk::Window &parent)
   depth_spin.set_adjustment(Gtk::Adjustment::create(width3, 4, width3));
   depth_box.set_sensitive(false);
 
-  tab_game.pack_start(game_box1, Gtk::PACK_SHRINK);
-  game_box1.set_spacing(6);
-  game_box1.pack_start(game_heading);
+  page_game_box.pack_start(game_heading, Gtk::PACK_SHRINK);
   game_heading.set_text("<span weight=\"bold\">Game</span>");
   game_heading.set_use_markup(true);
   game_heading.set_alignment(Gtk::ALIGN_START);
-  game_box1.pack_start(game_box2);
-  game_box2.set_margin_start(12);
-  game_box2.set_spacing(6);
-  game_box2.pack_start(mode_box1);
-  mode_box1.pack_start(mode_label1, Gtk::PACK_SHRINK);
-  mode_box1.set_spacing(6);
-  mode_label1.set_text("On level change: increase");
-  mode_box1.pack_start(mode_combo1, Gtk::PACK_SHRINK);
-  mode_combo1.append("speed");
-  mode_combo1.append("max. block size");
-  mode_combo1.append("superblock size");
-  mode_combo1.set_active(0);
-  mode_combo1.signal_changed().connect
-    (sigc::mem_fun(*this, &PrefsDialog::on_mode_combo1_signal_changed));
-  game_box2.pack_start(mode_box2);
-  mode_box2.set_margin_start(12);
-  mode_box2.set_spacing(6);
-  mode_box2.pack_start(mode_label2, Gtk::PACK_SHRINK);
-  mode_label2.set_text("and");
-  mode_box2.pack_start(mode_combo2, Gtk::PACK_SHRINK);
-  mode_combo2.append("decrease");
-  mode_combo2.append("keep fixed");
-  mode_combo2.append("increase");
-  mode_combo2.set_active(0);
-  mode_box2.pack_start(mode_label3, Gtk::PACK_SHRINK);
-  mode_label3.set_text("min. block size");
-  mode_box2.set_sensitive(false);
-  game_box2.pack_start(speed_box, Gtk::PACK_SHRINK);
+  game_heading.set_margin_top(12);
+  page_game_box.pack_start(game_box, Gtk::PACK_SHRINK);
+  game_box.set_margin_start(12);
+  game_box.set_spacing(6);
+  game_box.pack_start(mode1_box, Gtk::PACK_SHRINK);
+  mode1_box.set_spacing(6);
+  mode1_box.pack_start(mode1_label, Gtk::PACK_SHRINK);
+  mode1_label.set_text("On level change: increase");
+  mode1_box.pack_start(mode1_combo, Gtk::PACK_SHRINK);
+  mode1_combo.append("speed");
+  mode1_combo.append("max. block size");
+  mode1_combo.append("superblock size");
+  mode1_combo.set_active(0);
+  mode1_combo.signal_changed().connect
+    (sigc::mem_fun(*this, &PrefsDialog::on_mode1_combo_signal_changed));
+  game_box.pack_start(mode2_box, Gtk::PACK_SHRINK);
+  mode2_box.set_margin_start(12);
+  mode2_box.set_spacing(6);
+  mode2_box.pack_start(mode2_label1, Gtk::PACK_SHRINK);
+  mode2_label1.set_text("and");
+  mode2_box.pack_start(mode2_combo, Gtk::PACK_SHRINK);
+  mode2_combo.append("decrease");
+  mode2_combo.append("keep fixed");
+  mode2_combo.append("increase");
+  mode2_combo.set_active(0);
+  mode2_box.pack_start(mode2_label2, Gtk::PACK_SHRINK);
+  mode2_label2.set_text("min. block size");
+  mode2_box.set_sensitive(false);
+  game_box.pack_start(speed_box, Gtk::PACK_SHRINK);
   speed_box.set_spacing(6);
   speed_box.pack_start(speed_label, Gtk::PACK_SHRINK);
   speed_label.set_text("Initial speed level:");
   speed_box.pack_start(speed_spin, Gtk::PACK_SHRINK);
   speed_spin.set_adjustment(Gtk::Adjustment::create(5, 1, 9));
-  game_box2.pack_start(bricks_box, Gtk::PACK_SHRINK);
+  game_box.pack_start(bricks_box, Gtk::PACK_SHRINK);
   bricks_box.pack_start(bricks_label1, Gtk::PACK_SHRINK);
   bricks_box.set_spacing(6);
   bricks_label1.set_text("Initial block size: maximum");
@@ -250,7 +258,7 @@ PrefsDialog::PrefsDialog(Gtk::Window &parent)
   bricks_spin1.signal_value_changed().connect
     (sigc::mem_fun(*this,
 		   &PrefsDialog::on_bricks_spin1_signal_value_changed));
-  game_box2.pack_start(empty_box, Gtk::PACK_SHRINK);
+  game_box.pack_start(empty_box, Gtk::PACK_SHRINK);
   empty_box.set_spacing(6);
   empty_box.pack_start(empty_label1, Gtk::PACK_SHRINK);
   empty_label1.set_text("Remove lines with up to");
@@ -259,34 +267,30 @@ PrefsDialog::PrefsDialog(Gtk::Window &parent)
   empty_box.pack_start(empty_label2, Gtk::PACK_SHRINK);
   empty_label2.set_text("empty cells");
 
-  tab_game.pack_start(view_box1, Gtk::PACK_SHRINK);
-  view_box1.set_spacing(6);
-  view_box1.pack_start(view_heading);
+  page_game_box.pack_start(view_heading, Gtk::PACK_SHRINK);
   view_heading.set_text("<span weight=\"bold\">View</span>");
   view_heading.set_use_markup(true);
   view_heading.set_alignment(Gtk::ALIGN_START);
-  view_box1.pack_start(view_box2);
-  view_box2.set_margin_start(12);
-  view_box2.set_spacing(6);
-  view_box2.add(next_check);
+  view_heading.set_margin_top(12);
+  page_game_box.pack_start(view_box, Gtk::PACK_SHRINK);
+  view_box.set_margin_start(12);
+  view_box.set_spacing(6);
+  view_box.pack_start(next_check, Gtk::PACK_SHRINK);
   next_check.set_label("Preview next block");
   next_check.set_active(true);
-  view_box2.add(land_check);
+  view_box.pack_start(land_check, Gtk::PACK_SHRINK);
   land_check.set_label("Show where the block will land");
 
   // second tab
-  notebook.append_page(tab_controls, "Controls");
+  notebook.append_page(page_controls_box, "Controls");
 
-  tab_controls.set_border_width(12);
-  tab_controls.set_spacing(18);
-
-  tab_controls.pack_start(controls_box, Gtk::PACK_SHRINK);
-  controls_box.set_spacing(6);
-  controls_box.pack_start(two_heading);
+  page_controls_box.set_border_width(12);
+  page_controls_box.set_spacing(6);
+  page_controls_box.pack_start(two_heading, Gtk::PACK_SHRINK);
   two_heading.set_text("<span weight=\"bold\">2D controls</span>");
   two_heading.set_use_markup(true);
   two_heading.set_alignment(Gtk::ALIGN_START);
-  controls_box.pack_start(two_tree);
+  page_controls_box.pack_start(two_tree, Gtk::PACK_SHRINK);
   two_tree.set_margin_start(12);
   two_list = Gtk::ListStore::create(two_columns);
   two_tree.set_model(two_list);
@@ -303,11 +307,12 @@ PrefsDialog::PrefsDialog(Gtk::Window &parent)
   two_tree.get_column_cell_renderer(1)->signal_editing_started().connect
     (sigc::mem_fun(*this, &PrefsDialog::on_two_cell_editing_started));
 
-  controls_box.pack_start(three_heading);
+  page_controls_box.pack_start(three_heading, Gtk::PACK_SHRINK);
+  three_heading.set_margin_top(12);
   three_heading.set_text("<span weight=\"bold\">3D controls</span>");
   three_heading.set_use_markup(true);
   three_heading.set_alignment(Gtk::ALIGN_START);
-  controls_box.pack_start(three_tree);
+  page_controls_box.pack_start(three_tree, Gtk::PACK_SHRINK);
   three_tree.set_margin_start(12);
   three_list = Gtk::ListStore::create(three_columns);
   three_tree.set_model(three_list);
@@ -508,10 +513,10 @@ bool PrefsDialog::load()
 	      else if (name == "depth")
 		depth_spin.set_value(std::atoi(reader->get_value().c_str()));
 	      else if (name == "mode1")
-		mode_combo1.set_active
+		mode1_combo.set_active
 		  (std::atoi(reader->get_value().c_str()));
 	      else if (name == "mode2")
-		mode_combo2.set_active
+		mode2_combo.set_active
 		  (std::atoi(reader->get_value().c_str()));
 	      else if (name == "speed")
 		speed_spin.set_value(std::atoi(reader->get_value().c_str()));
