@@ -1,5 +1,5 @@
 /* preferences.h -- preferences dialog for falling blocks game.  -*- C++ -*-
-   Copyright (C) 2011-2015 Gerardo Ballabio
+   Copyright (C) 2011-2017 Gerardo Ballabio
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -36,69 +36,65 @@ private:
   // child widgets
   Gtk::Notebook notebook;
 
-  // first tab
-  ; Gtk::VBox tab_game;
+  // first page
+  ; Gtk::Box page_game_box;
 
-  ; ; Gtk::VBox geometry_box1;
-  ; ; ; Gtk::Label geometry_heading;
-  ; ; ; Gtk::VBox geometry_box2;
-  ; ; ; ; Gtk::RadioButton::Group geometry_group;
-  ; ; ; ; Gtk::RadioButton geometry_radio[sizeof(brick_shape) /
-					  sizeof(brick_shape[0])];
-  ; ; ; ; Gtk::CheckButton geometry_check;
-  ; ; ; ; Gtk::HBox width_box;
-  ; ; ; ; ; Gtk::Label width_label;
-  ; ; ; ; ; Gtk::SpinButton width_spin;
-  ; ; ; ; ; Gtk::HBox depth_box;
-  ; ; ; ; ; ; Gtk::Label depth_label;
-  ; ; ; ; ; ; Gtk::SpinButton depth_spin;
+  ; ; Gtk::Label geometry_heading;
+  ; ; Gtk::Box geometry_box;
+  ; ; ; Gtk::RadioButton::Group geometry_group;
+  ; ; ; Gtk::RadioButton geometry_radio[sizeof(brick_shape) /
+					sizeof(brick_shape[0])];
+  ; ; ; Gtk::CheckButton geometry_check;
+  ; ; ; Gtk::Box width_box;
+  ; ; ; ; Gtk::Label width_label;
+  ; ; ; ; Gtk::SpinButton width_spin;
+  ; ; ; ; Gtk::Box depth_box;
+  ; ; ; ; ; Gtk::Label depth_label;
+  ; ; ; ; ; Gtk::SpinButton depth_spin;
 
-  ; ; Gtk::VBox game_box1;
-  ; ; ; Gtk::Label game_heading;
-  ; ; ; Gtk::VBox game_box2;
-  ; ; ; ; Gtk::HBox mode_box1;
-  ; ; ; ; ; Gtk::Label mode_label1;
-  ; ; ; ; ; Gtk::ComboBoxText mode_combo1;
-  ; ; ; ; Gtk::HBox mode_box2;
-  ; ; ; ; ; Gtk::Label mode_label2;
-  ; ; ; ; ; Gtk::ComboBoxText mode_combo2;
-  ; ; ; ; ; Gtk::Label mode_label3;
-  ; ; ; ; Gtk::HBox speed_box;
-  ; ; ; ; ; Gtk::Label speed_label;
-  ; ; ; ; ; Gtk::SpinButton speed_spin;
-  ; ; ; ; Gtk::HBox bricks_box;
-  ; ; ; ; ; Gtk::Label bricks_label1;
-  ; ; ; ; ; Gtk::SpinButton bricks_spin1;
-  ; ; ; ; ; Gtk::Label bricks_label2;
-  ; ; ; ; ; Gtk::SpinButton bricks_spin2;
-  ; ; ; ; Gtk::HBox empty_box;
-  ; ; ; ; ; Gtk::Label empty_label1;
-  ; ; ; ; ; Gtk::SpinButton empty_spin;
-  ; ; ; ; ; Gtk::Label empty_label2;
+  ; ; Gtk::Label game_heading;
+  ; ; Gtk::Box game_box;
+  ; ; ; Gtk::Box mode1_box;
+  ; ; ; ; Gtk::Label mode1_label;
+  ; ; ; ; Gtk::ComboBoxText mode1_combo;
+  ; ; ; Gtk::Box mode2_box;
+  ; ; ; ; Gtk::Label mode2_label1;
+  ; ; ; ; Gtk::ComboBoxText mode2_combo;
+  ; ; ; ; Gtk::Label mode2_label2;
+  ; ; ; Gtk::Box speed_box;
+  ; ; ; ; Gtk::Label speed_label;
+  ; ; ; ; Gtk::SpinButton speed_spin;
+  ; ; ; Gtk::Box bricks_box;
+  ; ; ; ; Gtk::Label bricks_label1;
+  ; ; ; ; Gtk::SpinButton bricks_spin1;
+  ; ; ; ; Gtk::Label bricks_label2;
+  ; ; ; ; Gtk::SpinButton bricks_spin2;
+  ; ; ; Gtk::Box empty_box;
+  ; ; ; ; Gtk::Label empty_label1;
+  ; ; ; ; Gtk::SpinButton empty_spin;
+  ; ; ; ; Gtk::Label empty_label2;
 
-  ; ; Gtk::VBox view_box1;
-  ; ; ; Gtk::Label view_heading;
-  ; ; ; Gtk::VBox view_box2;
-  ; ; ; ; Gtk::CheckButton next_check;
-  ; ; ; ; Gtk::CheckButton land_check;
+  ; ; Gtk::Label view_heading;
+  ; ; Gtk::Box view_box;
+  ; ; ; Gtk::CheckButton next_check;
+  ; ; ; Gtk::CheckButton land_check;
 
-  // second tab
-  ; Gtk::VBox tab_controls;
-  ; ; Gtk::VBox controls_box;
-  ; ; ; Gtk::Label two_heading;
-  ; ; ; Gtk::TreeView two_tree;
-  ; ; ; ; Glib::RefPtr<Gtk::ListStore> two_list;
-  ; ; ; ; struct ColumnsModel : public Gtk::TreeModel::ColumnRecord
-	  {
-	    Gtk::TreeModelColumn<Glib::ustring> action;
-	    Gtk::TreeModelColumn<Glib::ustring> key;
+  // second page
+  ; Gtk::Box page_controls_box;
+  ; ; Gtk::Label two_heading;
+  ; ; Gtk::TreeView two_tree;
+  ; ; ; Glib::RefPtr<Gtk::ListStore> two_list;
+  ; ; ; struct ColumnsModel : public Gtk::TreeModel::ColumnRecord
+	{
+	  Gtk::TreeModelColumn<Glib::ustring> action;
+	  Gtk::TreeModelColumn<Glib::ustring> key;
 
-	    ColumnsModel() { add(action); add(key); }
-          } two_columns;
-  ; ; ; Gtk::Label three_heading;
-  ; ; ; Gtk::TreeView three_tree;
-  ; ; ; ; Glib::RefPtr<Gtk::ListStore> three_list;
-  ; ; ; ; ColumnsModel three_columns;
+	  ColumnsModel() { add(action); add(key); }
+        } two_columns;
+  ; ; Gtk::Label three_heading;
+  ; ; Gtk::TreeView three_tree;
+  ; ; ; Glib::RefPtr<Gtk::ListStore> three_list;
+  ; ; ; ColumnsModel three_columns;
 
   int width2, width3;
   int edit_keys;
@@ -109,7 +105,7 @@ protected:
   virtual bool on_key_press_event(GdkEventKey *);
   virtual void on_geometry_radio_signal_toggled();
   virtual void on_width_spin_signal_value_changed();
-  virtual void on_mode_combo1_signal_changed();
+  virtual void on_mode1_combo_signal_changed();
   virtual void on_bricks_spin1_signal_value_changed();
   virtual void on_two_cell_editing_started(Gtk::CellEditable *cell,
 					   const Glib::ustring &path);
@@ -125,8 +121,8 @@ public:
   bool get_reflection() const { return geometry_check.get_active(); }
   int get_width() const { return width_spin.get_value_as_int(); }
   int get_depth() const { return depth_spin.get_value_as_int(); }
-  int get_mode1() const { return mode_combo1.get_active_row_number(); }
-  int get_mode2() const { return mode_combo2.get_active_row_number(); }
+  int get_mode1() const { return mode1_combo.get_active_row_number(); }
+  int get_mode2() const { return mode2_combo.get_active_row_number(); }
   int get_speed() const { return speed_spin.get_value_as_int(); }
   int get_bricks_max() const { return bricks_spin1.get_value_as_int(); }
   int get_bricks_min() const { return bricks_spin2.get_value_as_int(); }
