@@ -1,5 +1,5 @@
 /* square.cc -- spatial groups for square bricks.  -*- C++ -*-
-   Copyright (C) 2011-2012 Gerardo Ballabio
+   Copyright (C) 2011-2015 Gerardo Ballabio
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -144,7 +144,7 @@ Gdk::Rectangle group_square::board_size(int size, int rows, int cols,
 }
 
 void group_square::draw_brick(Cairo::RefPtr<Cairo::Context> context,
-			      const coords &c, const Gdk::Color &color,
+			      const coords &c, const Gdk::RGBA &color,
 			      int size) const
 {
   const double lwidth = 2.0, margin = (lwidth + 1.0) * 0.5;
@@ -153,16 +153,16 @@ void group_square::draw_brick(Cairo::RefPtr<Cairo::Context> context,
   context->rectangle(c.x * size + margin, c.y * size + margin,
 		     size - 2.0 * margin, size - 2.0 * margin);
 
-  context->set_source_rgba(color.get_red_p(), color.get_green_p(),
-			   color.get_blue_p(), 0.8);
+  context->set_source_rgba(color.get_red(), color.get_green(),
+			   color.get_blue(), 0.8);
   context->fill_preserve();
-  context->set_source_rgba(color.get_red_p(), color.get_green_p(),
-			   color.get_blue_p(), 1.0);
+  context->set_source_rgba(color.get_red(), color.get_green(),
+			   color.get_blue(), 1.0);
   context->stroke();
 }
 
 void group_square::draw_shadow(Cairo::RefPtr<Cairo::Context> context,
-			       const coords &c, const Gdk::Color &color,
+			       const coords &c, const Gdk::RGBA &color,
 			       int size) const
 {
   const double lwidth = 2.0, margin = (lwidth + 1.0) * 0.5;
@@ -172,9 +172,8 @@ void group_square::draw_shadow(Cairo::RefPtr<Cairo::Context> context,
 		     size - 2.0 * margin, size - 2.0 * margin);
 
   const double dark = 0.8;
-  context->set_source_rgba(color.get_red_p() * dark,
-			   color.get_green_p() * dark,
-			   color.get_blue_p() * dark, 1.0);
+  context->set_source_rgba(color.get_red() * dark, color.get_green() * dark,
+			   color.get_blue() * dark, 1.0);
   context->stroke();
 }
 
