@@ -1,5 +1,5 @@
 /* triangle.cc -- spatial groups for triangular bricks.  -*- C++ -*-
-   Copyright (C) 2011-2013 Gerardo Ballabio
+   Copyright (C) 2011-2015 Gerardo Ballabio
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -206,7 +206,7 @@ Gdk::Rectangle group_triangle::board_size(int size, int rows, int cols,
 }
 
 void group_triangle::draw_brick(Cairo::RefPtr<Cairo::Context> context,
-				const coords &c, const Gdk::Color &color,
+				const coords &c, const Gdk::RGBA &color,
 				int size) const
 {
   if (type(c) < 0)
@@ -233,16 +233,16 @@ void group_triangle::draw_brick(Cairo::RefPtr<Cairo::Context> context,
     }
   context->close_path();
 
-  context->set_source_rgba(color.get_red_p(), color.get_green_p(),
-			   color.get_blue_p(), 0.8);
+  context->set_source_rgba(color.get_red(), color.get_green(),
+			   color.get_blue(), 0.8);
   context->fill_preserve();
-  context->set_source_rgba(color.get_red_p(), color.get_green_p(),
-			   color.get_blue_p(), 1.0);
+  context->set_source_rgba(color.get_red(), color.get_green(),
+			   color.get_blue(), 1.0);
   context->stroke();
 }
 
 void group_triangle::draw_shadow(Cairo::RefPtr<Cairo::Context> context,
-				 const coords &c, const Gdk::Color &color,
+				 const coords &c, const Gdk::RGBA &color,
 				 int size) const
 {
   if (type(c) < 0)
@@ -270,9 +270,8 @@ void group_triangle::draw_shadow(Cairo::RefPtr<Cairo::Context> context,
   context->close_path();
 
   const double dark = 0.8;
-  context->set_source_rgba(color.get_red_p() * dark,
-			   color.get_green_p() * dark,
-			   color.get_blue_p() * dark, 1.0);
+  context->set_source_rgba(color.get_red() * dark, color.get_green() * dark,
+			   color.get_blue() * dark, 1.0);
   context->stroke();
 }
 
