@@ -1,5 +1,5 @@
 /* triangle.h -- spatial groups for triangular bricks.  -*- C++ -*-
-   Copyright (C) 2011-2012 Gerardo Ballabio
+   Copyright (C) 2011-2015 Gerardo Ballabio
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -53,10 +53,10 @@ public:
   virtual Gdk::Rectangle board_size(int size, int rows, int cols,
 				    int layers) const;
   virtual void draw_brick(Cairo::RefPtr<Cairo::Context> context,
-			  const coords &c, const Gdk::Color &color,
+			  const coords &c, const Gdk::RGBA &color,
 			  int size) const;
   virtual void draw_shadow(Cairo::RefPtr<Cairo::Context> context,
-			   const coords &c, const Gdk::Color &color,
+			   const coords &c, const Gdk::RGBA &color,
 			   int size) const;
   virtual void draw_board(Cairo::RefPtr<Cairo::Context> context,
 			  int rows, int cols, int layers, int size) const;
